@@ -11,11 +11,11 @@ perldocSearch.indexData.modules = new Hash ({
   "charnames": "access to Unicode character names and named character sequences; also define character names",
   "constant": "Perl pragma to declare constants",
   "diagnostics": "produce verbose warning diagnostics",
-  "encoding": "allows you to write your script in non-ascii or non-utf8",
+  "encoding": "allows you to write your script in non-ASCII and non-UTF-8",
   "feature": "Perl pragma to enable new features",
   "fields": "compile-time class fields",
   "filetest": "Perl pragma to control the filetest permission operators",
-  "if": "use a Perl module if a condition holds",
+  "if": "use a Perl module if a condition holds (also can no a module)",
   "integer": "Perl pragma to use integer arithmetic instead of floating point",
   "less": "perl pragma to request less of something",
   "lib": "manipulate @INC at compile time",
@@ -45,33 +45,27 @@ perldocSearch.indexData.modules = new Hash ({
   "ExtUtils::Embed": "Utilities for embedding Perl in C/C++ applications",
   "Text::Tabs": "expand and unexpand tabs like unix expand(1) and unexpand(1)",
   "ExtUtils::MakeMaker": "Create a module Makefile",
-  "Log::Message::Simple": "Simplified interface to Log::Message",
   "PerlIO::encoding": "encoding layer",
   "Text::ParseWords": "parse text into an array of tokens or array of arrays",
   "IPC::Open2": "open a process for both reading and writing using open2()",
   "File::stat": "by-name interface to Perl's built-in stat() functions",
   "Pod::Simple::PullParserEndToken": "end-tokens from Pod::Simple::PullParser",
   "Math::Complex": "complex numbers and associated mathematical functions",
-  "ExtUtils::MM_VMS": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
   "File::DosGlob": "DOS like globbing and then some",
+  "ExtUtils::MM_VMS": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
   "IO::Poll": "Object interface to system poll call",
   "File::Spec::Functions": "portably perform operations on file names",
   "Socket": "networking constants and support functions",
-  "Module::Pluggable": "automatically give your module the ability to have plugins",
   "Parse::CPAN::Meta": "Parse META.yml and META.json CPAN metadata files",
   "Locale::Maketext::Simple": "Simple interface to Locale::Maketext::Lexicon",
   "Tie::File": "Access the lines of a disk file via a Perl array",
   "Encode::GSM0338": "ESTI GSM 03.38 Encoding",
   "File::GlobMapper": "Extend File Glob to Allow Input and Output Files",
-  "Module::Build::Platform::cygwin": "Builder class for Cygwin platform",
   "Devel::SelfStubber": "generate stubs for a SelfLoading module",
-  "Module::Build::Platform::Amiga": "Builder class for Amiga platforms",
   "File::Spec::Cygwin": "methods for Cygwin file specs",
   "Pod::Simple::HTML": "convert Pod to HTML",
   "Pod::Simple::HTMLBatch": "convert several Pod files to several HTML files",
-  "CGI::Util": "Internal utilities used by CGI module",
   "IO::Pipe": "supply object methods for pipes",
-  "Module::Build::YAML": "DEPRECATED",
   "ExtUtils::Command": "utilities to replace common UNIX commands in Makefiles etc.",
   "List::Util": "A selection of general-utility list subroutines",
   "Pod::Simple::Search": "find POD documents in directory trees",
@@ -82,59 +76,46 @@ perldocSearch.indexData.modules = new Hash ({
   "Archive::Tar": "module for manipulations of tar archives",
   "PerlIO::via::QuotedPrint": "PerlIO layer for quoted-printable strings",
   "TAP::Parser::Result::Pragma": "TAP pragma token.",
-  "File::CheckTree": "run many filetest checks on a tree",
   "File::Copy": "Copy files or filehandles",
   "Encode::EBCDIC": "EBCDIC Encodings",
-  "CPANPLUS::Internals::Search": "internals for searching for modules",
   "Net::Netrc": "OO interface to users netrc file",
   "Compress::Raw::Zlib": "Low-Level Interface to zlib compression library",
   "TAP::Parser::YAMLish::Writer": "Write YAMLish data",
   "Pod::Perldoc::GetOptsOO": "Customized option parser for Pod::Perldoc",
   "Thread::Queue": "Thread-safe queues",
-  "CPANPLUS::Dist::Sample": "Sample code to create your own Dist::* plugin",
   "Encode::Encoder": "Object Oriented Encoder",
   "Fcntl": "load the C Fcntl.h defines",
   "Test::Builder::Tester": "test testsuites that have been built withTest::Builder",
   "TAP::Formatter::Session": "Abstract base class for harness output delegate ",
-  "CPANPLUS::Error": "error handling for CPANPLUS",
   "TAP::Parser": "Parse TAP|Test::Harness::TAP output",
   "Hash::Util": "A selection of general-utility hash subroutines",
   "ExtUtils::MakeMaker::FAQ": "Frequently Asked Questions About MakeMaker",
-  "B::Lint::Debug": "Adds debugging stringification to B::",
   "Math::BigInt::FastCalc": "Math::BigInt::Calc with some XS for more speed",
   "Errno": "System errno constants",
   "Dumpvalue": "provides screen dump of Perl data.",
   "ExtUtils::testlib": "add blib/* directories to @INC",
   "Tie::RefHash": "use references as hash keys",
   "IO::Uncompress::RawInflate": "Read RFC 1951 files/buffers",
-  "TAP::Parser::Utils": "Internal TAP::Parser utilities",
-  "Module::Build::Platform::VMS": "Builder class for VMS platforms",
   "ExtUtils::MM_DOS": "DOS specific subclass of ExtUtils::MM_Unix",
-  "CPANPLUS::Internals::Source::Memory": "In memory implementation",
-  "CPANPLUS::Backend": "programmer's interface to CPANPLUS",
   "CPAN::Kwalify": "Interface between CPAN.pm and Kwalify.pm",
   "DBM_Filter::null": "filter for DBM_Filter",
   "ExtUtils::CBuilder": "Compile and link C code for Perl modules",
   "DBM_Filter::compress": "filter for DBM_Filter",
   "IO::Uncompress::Gunzip": "Read RFC 1952 files/buffers",
-  "Encode::KR": "Korean Encodings",
-  "Exporter": "Implements default import method for modules",
   "ExtUtils::Constant::XS": "generate C code for XS modules' constants.",
+  "Exporter": "Implements default import method for modules",
+  "Encode::KR": "Korean Encodings",
   "AutoLoader": "load subroutines only on demand",
-  "Module::Build::Platform::aix": "Builder class for AIX platform",
   "Pod::Text::Color": "Convert POD data to formatted color ASCII text",
   "Time::tm": "internal object used by Time::gmtime and Time::localtime",
   "Net::NNTP": "NNTP Client class",
   "IO": "load various IO modules",
   "Module::Load": "runtime require of both modules and files",
   "Encode::KR::2022_KR": "internally used by Encode::KR",
-  "CPANPLUS::Shell::Default": "the default CPANPLUS shell",
   "ExtUtils::Manifest": "utilities to write and check a MANIFEST file",
   "TAP::Parser::Scheduler::Spinner": "A no-op job.",
   "Getopt::Long": "Extended processing of command line options",
   "Digest::base": "Digest base class",
-  "Pod::LaTeX": "Convert Pod data to formatted Latex",
-  "Module::Build::PPMMaker": "Perl Package Manager file creation",
   "PerlIO::via": "Helper class for PerlIO layers implemented in perl",
   "SelfLoader": "load functions only on demand",
   "TAP::Parser::Iterator": "Base class for TAP source iterators",
@@ -152,12 +133,10 @@ perldocSearch.indexData.modules = new Hash ({
   "Pod::Html": "module to convert pod files to HTML",
   "Pod::Perldoc::ToNroff": "let Perldoc convert Pod to nroff",
   "TAP::Parser::Result::Comment": "Comment result token.",
-  "CPANPLUS::Selfupdate": "self-updating for CPANPLUS",
   "ExtUtils::Packlist": "manage .packlist files",
   "TAP::Formatter::Console::ParallelSession": "Harness output delegate for parallel console output",
   "Thread": "Manipulate threads in Perl (for old code only)",
   "Unicode::Collate": "Unicode Collation Algorithm",
-  "CPANPLUS::Module::Fake": "fake module object for internal use",
   "IO::Compress::Gzip": "Write RFC 1952 files/buffers",
   "Time::HiRes": "High resolution alarm, sleep, gettimeofday, interval timers",
   "Net::protoent": "by-name interface to Perl's built-in getproto*() functions",
@@ -170,56 +149,42 @@ perldocSearch.indexData.modules = new Hash ({
   "Pod::PlainText": "Convert POD data to formatted ASCII text",
   "IO::Socket::INET": "Object interface for AF_INET domain sockets",
   "Encode::Byte": "Single Byte Encodings",
-  "Module::Build": "Build and install Perl modules",
   "DynaLoader": "Dynamically load C libraries into Perl code",
-  "CPANPLUS::Shell::Default::Plugins::Source": "read in CPANPLUS commands",
   "Tie::Scalar": "base class definitions for tied scalars",
-  "CPANPLUS::Module::Author::Fake": "dummy author object for CPANPLUS",
-  "CPANPLUS::Internals::Source::SQLite": "SQLite implementation",
   "Math::Trig": "trigonometric functions",
   "TAP::Object": "Base class that provides common functionality to all TAP::* modules",
   "Tie::Array": "base class for tied arrays",
   "I18N::Langinfo": "query locale information",
-  "CPANPLUS::Shell::Default::Plugins::Remote": "connect to a remote CPANPLUS",
   "ExtUtils::CBuilder::Platform::Windows": "Builder class for Windows platforms",
   "Test::Harness": "Run Perl standard test scripts with statistics",
   "ExtUtils::MM_Win95": "method to customize MakeMaker for Win9X",
   "Attribute::Handlers": "Simpler definition of attribute handlers",
-  "Term::UI": "Term::ReadLine UI made easy",
   "Memoize::NDBM_File": "glue to provide EXISTS for NDBM_File for Storable use",
   "Net::servent": "by-name interface to Perl's built-in getserv*() functions",
-  "Module::Pluggable::Object": "automatically give your module the ability to have plugins",
-  "Class::Struct": "declare struct-like datatypes as Perl classes",
   "Encode::Guess": "Guesses encoding from data",
-  "CPANPLUS::Internals::Source": "internals for updating source files",
+  "Class::Struct": "declare struct-like datatypes as Perl classes",
   "Pod::Perldoc::ToChecker": "let Perldoc check Pod for errors",
   "Test::Builder": "Backend for building test libraries",
   "DBM_Filter::int32": "filter for DBM_Filter",
   "ExtUtils::MM_NW5": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
-  "CGI::Carp": "CGI routines for writing to the HTTPD (or other) error log",
-  "Module::Build::Compat": "Compatibility with ExtUtils::MakeMaker",
   "Getopt::Std": "Process single-character switches with switch clustering",
-  "Module::Build::Platform::MPEiX": "Builder class for MPEiX platforms",
   "ExtUtils::MM_Win32": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
-  "Object::Accessor": "interface to create per object accessors",
   "CPAN::Debug": "internal debugging for CPAN.pm",
   "File::Fetch": "A generic file fetching mechanism",
   "Term::ReadLine": "Perl interface to various readline packages.If no real package is found, substitutes stubs instead of basic functions.",
   "ExtUtils::Constant::Utils": "helper functions for ExtUtils::Constant",
   "Scalar::Util": "A selection of general-utility scalar subroutines",
   "Locale::Language": "standard codes for language identification",
-  "Benchmark": "benchmark running times of Perl code",
   "FindBin": "Locate directory of original perl script",
+  "Benchmark": "benchmark running times of Perl code",
   "Net::hostent": "by-name interface to Perl's built-in gethost*() functions",
   "ExtUtils::MY": "ExtUtils::MakeMaker subclass for customization",
   "FileCache": "keep more files open than the system permits",
-  "CPANPLUS": "API & CLI access to the CPAN mirrors",
   "Pod::Select": "extract selected sections of POD from input",
   "Locale::Maketext::GutsLoader": "Deprecated module to load Locale::Maketext utf8 code",
   "TAP::Parser::Result::Plan": "Plan result token.",
   "Encode::JP": "Japanese Encodings",
   "Pod::Checker": "check pod documents for syntax errors",
-  "Module::Build::Platform::os2": "Builder class for OS/2 platform",
   "Pod::Text::Termcap": "Convert POD data to ASCII text with format escapes",
   "Locale::Maketext::Guts": "Deprecated module to load Locale::Maketext utf8 code",
   "ExtUtils::Mkbootstrap": "make a bootstrap file for use by DynaLoader",
@@ -232,22 +197,15 @@ perldocSearch.indexData.modules = new Hash ({
   "Safe": "Compile and execute code in restricted compartments",
   "IO::File": "supply object methods for filehandles",
   "ExtUtils::ParseXS": "converts Perl XS code into C code",
-  "CPANPLUS::Module::Checksums": "checking the checksum of a distribution",
-  "Module::Build::ModuleInfo": "DEPRECATED",
   "Encode::MIME::Header": "MIME 'B' and 'Q' header encoding",
   "File::Find": "Traverse a directory tree.",
-  "Module::Build::Platform::EBCDIC": "Builder class for EBCDIC platforms",
   "DBM_Filter::encode": "filter for DBM_Filter",
   "Test": "provides a simple framework for writing test scripts",
   "Hash::Util::FieldHash": "Support for Inside-Out Classes",
-  "Module::Build::Version": "DEPRECATED",
   "Exporter::Heavy": "Exporter guts",
   "App::Prove::State::Result": "Individual test suite results.",
-  "CPANPLUS::Shell::Default::Plugins::CustomSource": "add custom sources to CPANPLUS",
-  "CPANPLUS::Module::Author": "CPAN author object for CPANPLUS",
   "Time::localtime": "by-name interface to Perl's built-in localtime() function",
   "Module::Load::Conditional": "Looking up module information / loading at runtime",
-  "CPANPLUS::Backend::RV": "return value objects",
   "Pod::Functions": "Group Perl's functions a la perlfunc.pod",
   "File::Spec::Epoc": "methods for Epoc file specs",
   "Devel::PPPort": "Perl/Pollution/Portability",
@@ -255,9 +213,7 @@ perldocSearch.indexData.modules = new Hash ({
   "IO::Socket": "Object interface to socket communications",
   "File::Temp": "return name and handle of a temporary file safely",
   "Locale::Script": "standard codes for script identification",
-  "Term::UI::History": "history function",
   "TAP::Parser::Result::Test": "Test result token.",
-  "CGI::Push": "Simple Interface to Server Push",
   "Digest::MD5": "Perl interface to the MD5 Algorithm",
   "Text::Balanced": "Extract delimited text sequences from strings.",
   "Net::Domain": "Attempt to evaluate the current host's internet name and domain",
@@ -267,14 +223,10 @@ perldocSearch.indexData.modules = new Hash ({
   "Memoize::Storable": "store Memoized data in Storable database",
   "Unicode::UCD": "Unicode character database",
   "Encode::TW": "Taiwan-based Chinese Encodings",
-  "Module::Build::Cookbook": "Examples of Module::Build Usage",
   "Pod::Perldoc": "Look up Perl documentation in Pod format.",
-  "Module::Build::ConfigData": "Configuration for Module::Build",
   "AutoSplit": "split a package for autoloading",
-  "Module::Build::Platform::Default": "Stub class for unknown platforms",
   "TAP::Parser::Result::Version": "TAP syntax version token.",
   "Locale::Country": "standard codes for country identification",
-  "Module::Build::Platform::Unix": "Builder class for Unix platforms",
   "File::Path": "Create or remove directory trees",
   "ExtUtils::Mksymlists": "write linker options files for dynamic extension",
   "CPAN::HandleConfig": "internal configuration handling for CPAN.pm",
@@ -288,8 +240,6 @@ perldocSearch.indexData.modules = new Hash ({
   "TAP::Formatter::Console": "Harness output delegate for default console output",
   "B::Deparse": "Perl compiler backend to produce perl code",
   "FileHandle": "supply object methods for filehandles",
-  "CPANPLUS::Dist": "base class for plugins",
-  "CPANPLUS::Dist::Build": "CPANPLUS plugin to install packages that use Build.PL",
   "File::Glob": "Perl extension for BSD glob routine",
   "Digest::file": "Calculate digests of files",
   "Encode::Symbol": "Symbol Encodings",
@@ -303,49 +253,38 @@ perldocSearch.indexData.modules = new Hash ({
   "TAP::Parser::Source": "a TAP source & meta data about it",
   "ExtUtils::MM_UWIN": "U/WIN specific subclass of ExtUtils::MM_Unix",
   "ExtUtils::MM_QNX": "QNX specific subclass of ExtUtils::MM_Unix",
-  "Term::ANSIColor": "Color screen output using ANSI escape sequences",
   "Pod::Simple::Checker": "check the Pod syntax of a document",
+  "Term::ANSIColor": "Color screen output using ANSI escape sequences",
   "TAP::Parser::Multiplexer": "Multiplex multiple TAP::Parsers",
   "MIME::QuotedPrint": "Encoding and decoding of quoted-printable strings",
   "Time::Seconds": "a simple API to convert seconds to other date values",
   "B": "The Perl Compiler Backend",
-  "Test::More": "yet another framework for writing test scripts",
   "TAP::Base": "Base class that provides common functionality to TAP::Parserand TAP::Harness",
+  "Test::More": "yet another framework for writing test scripts",
   "B::Concise": "Walk Perl syntax tree, printing concise info about ops",
   "PerlIO": "On demand loader for PerlIO layers and root of PerlIO::* name space",
   "ExtUtils::MM_BeOS": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
   "TAP::Parser::Iterator::Process": "Iterator for process-based TAP sources",
   "IO::Dir": "supply object methods for directory handles",
-  "CGI::Cookie": "Interface to HTTP Cookies",
-  "UNIVERSAL": "base class for ALL classes (blessed references)",
   "IO::Uncompress::Inflate": "Read RFC 1950 files/buffers",
-  "Log::Message::Item": "Message objects for Log::Message",
+  "UNIVERSAL": "base class for ALL classes (blessed references)",
   "Test::Simple": "Basic utilities for writing tests.",
   "ExtUtils::MM_Cygwin": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
   "Fatal": "Replace functions with equivalents which succeed or die",
   "IPC::Msg": "SysV Msg IPC object class",
-  "CPANPLUS::Module": "CPAN module objects for CPANPLUS",
   "B::Terse": "Walk Perl syntax tree, printing terse info about ops",
-  "Archive::Extract": "A generic archive extracting mechanism",
-  "Module::Build::Platform::MacOS": "Builder class for MacOS platforms",
   "CPAN": "query, download and build perl modules from CPAN sites",
-  "Module::Build::Notes": "Create persistent distribution configuration modules",
-  "Module::Build::Base": "Default methods for Module::Build",
   "Net::netent": "by-name interface to Perl's built-in getnet*() functions",
   "Encode": "character encodings in Perl",
-  "Devel::InnerPackage": "find all the inner packages of a package",
-  "CPANPLUS::Internals::Fetch": "internals for fetching files",
   "IO::Zlib": "IO:: style interface to Compress::Zlib",
   "Memoize::SDBM_File": "glue to provide EXISTS for SDBM_File for Storable use",
   "Net::FTP": "FTP Client class",
-  "Package::Constants": "List all constants declared in a package",
   "Pod::Man": "Convert POD data to formatted *roff input",
   "Net::POP3": "Post Office Protocol 3 Client class (RFC1939)",
   "B::Xref": "Generates cross reference reports for Perl programs",
   "ExtUtils::MM_VOS": "VOS specific subclass of ExtUtils::MM_Unix",
   "Math::BigRat": "Arbitrary big rational numbers",
   "TAP::Formatter::File::Session": "Harness output delegate for file output",
-  "CPANPLUS::Dist::Autobundle": "distribution class for installation snapshots",
   "IO::Uncompress::Unzip": "Read zip files/buffers",
   "Encode::Encoding": "Encode Implementation Base Class",
   "IO::Uncompress::Bunzip2": "Read bzip2 files/buffers",
@@ -358,24 +297,16 @@ perldocSearch.indexData.modules = new Hash ({
   "Pod::Parser": "base class for creating POD filters and translators",
   "SelectSaver": "save and restore selected file handle",
   "Time::gmtime": "by-name interface to Perl's built-in gmtime() function",
-  "CGI::Fast": "CGI Interface for Fast CGI",
-  "CGI": "Handle Common Gateway Interface requests and responses",
   "IPC::SharedMem": "SysV Shared Memory IPC object class",
-  "CPANPLUS::Shell::Classic": "CPAN.pm emulation for CPANPLUS",
   "App::Prove::State": "State storage for the prove command.",
   "DBM_Filter::utf8": "filter for DBM_Filter",
   "Time::Local": "efficiently compute time from local and GMT time",
   "Pod::Simple::RTF": "format Pod as RTF",
   "Pod::ParseLink": "Parse an L&lt;&gt; formatting code in POD text",
-  "Log::Message::Handlers": "Message handlers for Log::Message",
   "Pod::Simple::PullParser": "a pull-parser interface to parsing Pod",
   "Tie::Handle": "base class definitions for tied handles",
-  "Module::Build::Platform::RiscOS": "Builder class for RiscOS platforms",
   "Memoize::ExpireFile": "test for Memoize expiration semantics",
-  "CPANPLUS::Config": "configuration defaults and heuristics for CPANPLUS",
-  "Text::Soundex": "Implementation of the soundex algorithm.",
   "IO::Select": "OO interface to the select system call",
-  "CPANPLUS::Internals::Utils": "convenience functions for CPANPLUS",
   "Locale::Maketext": "framework for localization",
   "I18N::Collate": "compare 8-bit scalar data according to the current locale",
   "Pod::Simple::Text": "format Pod as plaintext",
@@ -405,25 +336,21 @@ perldocSearch.indexData.modules = new Hash ({
   "Math::BigInt": "Arbitrary size integer/float math package",
   "IO::Compress::Base": "Base Class for IO::Compress modules ",
   "TAP::Parser::Result::Bailout": "Bailout result token.",
-  "B::Lint": "Perl lint",
   "Pod::Find": "find POD documents in directory trees",
+  "Net::FTP::dataconn": "FTP Client data connection class",
   "English": "use nice English (or awk) names for ugly punctuation variables",
   "Pod::InputObjects": "objects representing POD input paragraphs, commands, etc.",
-  "CPANPLUS::Configure": "configuration for CPANPLUS",
   "Tie::Hash": "base class definitions for tied hashes",
-  "Log::Message::Config": "Configuration options for Log::Message",
   "TAP::Parser::Result::YAML": "YAML result token.",
   "Math::BigInt::Calc": "Pure Perl module to support Math::BigInt",
   "TAP::Parser::Grammar": "A grammar for the Test Anything Protocol.",
   "File::Spec::Mac": "File::Spec for Mac OS (Classic)",
-  "Filter::Simple": "Simplified source filtering",
   "XSLoader": "Dynamically load C libraries into Perl code",
+  "Filter::Simple": "Simplified source filtering",
   "IO::Handle": "supply object methods for I/O handles",
-  "Module::Build::Platform::darwin": "Builder class for Mac OS X platform",
   "TAP::Formatter::Console::Session": "Harness output delegate for default console output",
   "Carp": "alternative warn and die for modules",
   "Search::Dict": "look - search for key in dictionary file",
-  "CPANPLUS::Dist::MM": "distribution class for MakeMaker related modules",
   "ExtUtils::Liblist": "determine libraries to use and how to use them",
   "CPAN::Queue": "internal queue support for CPAN.pm",
   "ExtUtils::Constant::Base": "base class for ExtUtils::Constant objects",
@@ -433,12 +360,11 @@ perldocSearch.indexData.modules = new Hash ({
   "Time::Piece": "Object Oriented time objects",
   "Pod::Simple::DumpAsXML": "turn Pod into XML",
   "DB": "programmatic interface to the Perl debugging API",
-  "Module::Build::Platform::VOS": "Builder class for VOS platforms",
   "Data::Dumper": "stringified perl data structures, suitable for both printing and eval",
   "IPC::Cmd": "finding and running system commands made easy",
   "Env": "perl module that imports environment variables as scalars or arrays",
-  "I18N::LangTags::Detect": "detect the user's language preferences",
   "Encode::CN": "China-based Chinese Encodings",
+  "I18N::LangTags::Detect": "detect the user's language preferences",
   "Config::Extensions": "hash lookup of which core extensions were built.",
   "Pod::Perldoc::ToText": "let Perldoc render Pod as plaintext",
   "Encode::Unicode": "Various Unicode Transformation Formats",
@@ -449,9 +375,7 @@ perldocSearch.indexData.modules = new Hash ({
   "Encode::Config": "internally used by Encode",
   "Pod::Simple::DumpAsText": "dump Pod-parsing events as text",
   "Encode::JP::H2Z": "internally used by Encode::JP::2022_JP*",
-  "CGI::Switch": "Backward compatibility module for defunct CGI::Switch",
   "Digest": "Modules that calculate message digests",
-  "CPANPLUS::Internals::Extract": "internals for archive extraction",
   "Math::BigFloat": "Arbitrary size floating point math package",
   "Net::Time": "time and daytime network client interface",
   "Module::Loaded": "mark modules as loaded or unloaded",
@@ -462,7 +386,6 @@ perldocSearch.indexData.modules = new Hash ({
   "Memoize::ExpireTest": "test for Memoize expiration semantics",
   "ExtUtils::Install": "install files from here to there",
   "IPC::Open3": "open a process for reading, writing, and error handling using open3()",
-  "CPANPLUS::Internals::Report": "internals for sending test reports",
   "ExtUtils::MM_Darwin": "special behaviors for OS X",
   "Net::Ping": "check a remote host for reachability",
   "Pod::Perldoc::ToMan": "let Perldoc render Pod as man pages",
@@ -471,11 +394,10 @@ perldocSearch.indexData.modules = new Hash ({
   "App::Prove": "Implements the prove command.",
   "Thread::Semaphore": "Thread-safe semaphores",
   "Compress::Zlib": "Interface to zlib compression library",
-  "NEXT": "Provide a pseudo-class NEXT (et al) that allows method redispatch",
   "Tie::SubstrHash": "Fixed-table-size, fixed-key-length hashing",
-  "CGI::Apache": "Backward compatibility module for CGI.pm",
-  "NDBM_File": "Tied access to ndbm files",
+  "NEXT": "Provide a pseudo-class NEXT (et al) that allows method redispatch",
   "Tie::StdHandle": "base class definitions for tied handles",
+  "NDBM_File": "Tied access to ndbm files",
   "CPAN::Tarzip": "internal handling of tar archives for CPAN.pm",
   "TAP::Parser::Aggregator": "Aggregate TAP::Parser results",
   "Net::SMTP": "Simple Mail Transfer Protocol Client",
@@ -484,15 +406,10 @@ perldocSearch.indexData.modules = new Hash ({
   "Encode::Unicode::UTF7": "UTF-7 encoding",
   "Pod::Simple::TextContent": "get the text content of Pod",
   "File::Basename": "Parse file paths into directory, filename and suffix.",
-  "Log::Message": "A generic message storing mechanism;",
   "Devel::Peek": "A data debugging tool for the XS programmer",
-  "CPANPLUS::Dist::Base": "Base class for custom distribution classes",
-  "CGI::Pretty": "module to produce nicely formatted HTML code",
   "File::Spec::Unix": "File::Spec for Unix, base for other File::Spec modules",
-  "CPANPLUS::Dist::Build::Constants": "Constants for CPANPLUS::Dist::Build",
-  "CPANPLUS::Internals": "CPANPLUS internals",
-  "ExtUtils::MM": "OS adjusted ExtUtils::MakeMaker subclass",
   "TAP::Parser::YAMLish::Reader": "Read YAMLish data from iterator",
+  "ExtUtils::MM": "OS adjusted ExtUtils::MakeMaker subclass",
   "Digest::SHA": "Perl extension for SHA-1/224/256/384/512",
   "Locale::Currency": "standard codes for currency identification",
   "DirHandle": "supply object methods for directory handles",
@@ -505,14 +422,12 @@ perldocSearch.indexData.modules = new Hash ({
   "Pod::Simple::Debug": "put Pod::Simple into trace/debug mode",
   "IO::Compress::Bzip2": "Write bzip2 files/buffers",
   "Pod::Simple::PullParserTextToken": "text-tokens from Pod::Simple::PullParser",
-  "CPANPLUS::Shell": "base class for CPANPLUS shells",
   "Memoize": "Make functions faster by trading space for time",
   "Term::Complete": "Perl word completion module",
   "POSIX": "Perl interface to IEEE Std 1003.1",
   "User::pwent": "by-name interface to Perl's built-in getpw*() functions",
   "Tie::Hash::NamedCapture": "Named regexp capture buffers",
   "DBM_Filter": "Filter DBM keys/values ",
-  "Module::Build::Platform::Windows": "Builder class for Windows platforms",
   "O": "Generic interface to Perl Compiler backends",
   "AnyDBM_File": "provide framework for multiple DBMs",
   "TAP::Parser::Iterator::Array": "Iterator for array-based TAP sources"
